import {
  CacheType,
  ChatInputCommandInteraction,
  Interaction,
} from "discord.js";
import config from "config";
import EventEmitter from "events";
import DiscordService from "Services/discord.service";
import PrismaService from "Services/prisma.service";

export default class DiscordController extends EventEmitter {
  private discordService!: DiscordService;
  private prismaService: PrismaService;

  constructor() {
    super();
    this.discordService = new DiscordService();
    this.prismaService = new PrismaService();
    this.discordService.client.once("ready", () => {
      console.log("Listening...");
    });
    this.discordService.client.on(
      "interactionCreate",
      this.handleInteraction.bind(this)
    );
  }

  async init() {
    await this.discordService.init();
  }

  async handleInteraction(interaction: Interaction<CacheType>) {
    if (!interaction.isChatInputCommand()) return;

    const { commandName } = interaction;

    switch (commandName) {
      case "quote":
        await this.quote(interaction);
      default:
        break;
    }
  }

  async quote(interaction: ChatInputCommandInteraction<CacheType>) {
    // find the channel with configured id
    const channel = this.discordService.client.channels.cache.find(
      (ch) => ch.id === config.discord.channelId
    );

    if (channel?.isTextBased()) {
      const content = interaction.options.getString("content") || "";

      // send quote content as message
      await this.prismaService.client.message.create({
        data: {
          content,
          userName: interaction.user.username,
        },
      });

      await channel.send(content);

      await interaction.reply({
        content: "Completed!",
        ephemeral: true,
      });
      return;
    }
  }
}
