import {
  Client,
  IntentsBitField,
  Routes,
  SlashCommandBuilder,
} from "discord.js";
import { REST } from "@discordjs/rest";
import config from "config";

const COMMANDS = [
  new SlashCommandBuilder()
    .setName("quote")
    .setDescription("Lets you post a qoute without showing your name")
    .addStringOption((option) =>
      option
        .setName("content")
        .setDescription("The content of the quote")
        .setRequired(true)
    ),
].map((command) => command.toJSON());

export default class DiscordService {
  rest: REST;
  client: Client<boolean>;
  constructor() {
    this.rest = new REST({ version: "10" }).setToken(config.discord.token);

    this.client = new Client({ intents: [IntentsBitField.Flags.Guilds] });
  }

  async init() {
    try {
      await this.rest.put(
        Routes.applicationCommands(config.discord.applicationId),
        {
          body: COMMANDS,
        }
      );
      console.log("Successfully added commands");

      await this.client.login(config.discord.token);
    } catch (e) {
      console.error(e);
    }
  }
}
